@@ -11,7 +11,7 @@ from .dictionary import _define_words_in_sentence
 
 
 def get_listening_challenge(source, course):
-    if not course.settings.audio_files_enabled:
+    if not course.settings.audio_settings.enabled:
         return []
 
     return [
